/**
  *  \file planetscentral/mailout/message.h
  *  \brief Mailout: Message
  */
#ifndef C2SERVER_PLANETSCENTRAL_MAILOUT_MESSAGE_H
#define C2SERVER_PLANETSCENTRAL_MAILOUT_MESSAGE_H

#include "planetscentral/dbclient/dbsubtree.h"

/** A message. Represents a message that is being worked on,
    to access its database properties. */
class Message {
 public:
    Message(DbSubtree root, int32_t mid, string_t state);

    DbHashStringField templateName();
    DbHashStringField uniqueId();
    DbHash arguments();
    DbStringList attachments();
    DbStringSet receivers();
    DbHashIntField expireTime();

    void remove();
    void send();

    int32_t getId() const;
    
 private:
    DbSubtree root;
    DbSubtree msg;
    int32_t mid;
    string_t state;
};

std::auto_ptr<Message> allocateMessage(DbSubtree root);

/** Get message identifier. */
inline int32_t
Message::getId() const
{
    return mid;
}

#endif
