/**
  *  \file planetscentral/net/url.h
  *  \brief Networking: URL
  */
#ifndef C2SERVER_PLANETSCENTRAL_NET_URL_H
#define C2SERVER_PLANETSCENTRAL_NET_URL_H

#include "cpluslib/string.h"

/** An URL pointing to a file resource. This represents/splits apart
    a http- or ftp-style URL, i.e. "proto://host:port/file" format

    \todo handle fragment-identifiers meaningfully. They remain part
    of the path so far, and are sent to the webserver. They are also
    processed as part of a parameter section in trimParameters(). */
class Url {
    string_t m_Protocol;
    string_t m_Host;
    string_t m_Path;
    string_t m_User;
    int m_Port;
    bool m_Valid;

 public:
    Url();

    ~Url();

    bool parse(string_t s);

    string_t getProtocol() const
        { return m_Protocol; }
    string_t getHost() const
        { return m_Host; }
    string_t getPath() const
        { return m_Path; }
    string_t getUser() const
        { return m_User; }
    int getPort() const
        { return m_Port; }

    string_t getBaseName() const;

    string_t toString() const;

    void reset()
        { m_Valid = false; }

    bool isValid() const
        { return m_Valid; }

    // void trimParameters(KVEnumerator& e);
    // static void trimParameters(string_t& s, KVEnumerator& e);
};


#endif
